==> thutils-0.1.8.tar.gz: thutils-0.1.8/test/test_main.py <==
# encoding: utf-8

'''
@author: Tsuyoshi Hombashi

:required:
    https://pypi.python.org/pypi/pytest
'''

import os

import pytest

import thutils
from thutils.main import *
import thutils.common as common
import thutils.gfile as gfile
import thutils.sqlite as sql


@pytest.fixture
def sys_wrapper():
    return thutils.syswrapper.SystemWrapper()

TEST_DIR_PATH = os.path.dirname(os.path.realpath(__file__))


def return0_func():
    return 0


def return1_func():
    return 1


def raise_InvalidFilePathError():
    raise gfile.InvalidFilePathError()


def raise_FileNotFoundError():
    raise gfile.FileNotFoundError()


def raise_IOError():
    raise IOError()


def raise_ValueError():
    raise ValueError()


def raise_ImportError():
    raise ImportError()


def raise_PermissionError():
    raise thutils.PermissionError()


def raise_KeyboardInterrupt():
    raise KeyboardInterrupt


def raise_DatabaseError():
    raise sql.DatabaseError()


class Test_Main:

    @pytest.mark.parametrize(["value", "expected"], [
        [return0_func, 0],
        [return1_func, 1],
        [raise_InvalidFilePathError, EX_NOINPUT],
        [raise_FileNotFoundError, EX_NOINPUT],
        [raise_IOError, EX_IOERR],
        [raise_ValueError, EX_SOFTWARE],
        [raise_ImportError, EX_OSFILE],
        [raise_PermissionError, EX_NOPERM],
        [raise_KeyboardInterrupt, 1],
        [raise_DatabaseError, EX_DATAERR],
    ])
    def test_normal(self, value, expected):
        main = Main(value)
        assert main() == expected

    @pytest.mark.parametrize(["value", "args", "expected"], [
        [None, None, TypeError],
    ])
    def test_exception(self, value, args, expected):
        with pytest.raises(expected):
            main = Main(value, args)
            main()

==> thutils-0.1.13.tar.gz: thutils-0.1.13/test/test_main.py <==
# encoding: utf-8

'''
@author: Tsuyoshi Hombashi

:required:
    https://pypi.python.org/pypi/pytest
'''

import os

import pytest

import thutils
from thutils.main import *
import thutils.common as common
import thutils.gfile as gfile
import thutils.sqlite as sql


@pytest.fixture
def sys_wrapper():
    return thutils.subprocwrapper.SubprocessWrapper()

TEST_DIR_PATH = os.path.dirname(os.path.realpath(__file__))


def return0_func():
    return 0


def return1_func():
    return 1


def raise_InvalidFilePathError():
    raise gfile.InvalidFilePathError()


def raise_FileNotFoundError():
    raise gfile.FileNotFoundError()


def raise_IOError():
    raise IOError()


def raise_ValueError():
    raise ValueError()


def raise_ImportError():
    raise ImportError()


def raise_PermissionError():
    raise thutils.PermissionError()


def raise_KeyboardInterrupt():
    raise KeyboardInterrupt


def raise_DatabaseError():
    raise sql.DatabaseError()


class Test_Main:

    @pytest.mark.parametrize(["value", "expected"], [
        [return0_func, 0],
        [return1_func, 1],
        [raise_InvalidFilePathError, EX_NOINPUT],
        [raise_FileNotFoundError, EX_NOINPUT],
        [raise_IOError, EX_IOERR],
        [raise_ValueError, EX_SOFTWARE],
        [raise_ImportError, EX_OSFILE],
        [raise_PermissionError, EX_NOPERM],
        [raise_KeyboardInterrupt, 1],
        [raise_DatabaseError, EX_DATAERR],
    ])
    def test_normal(self, value, expected):
        main = Main(value)
        assert main() == expected

    @pytest.mark.parametrize(["value", "args", "expected"], [
        [None, None, TypeError],
    ])
    def test_exception(self, value, args, expected):
        with pytest.raises(expected):
            main = Main(value, args)
            main()
